import type { Coordinate } from './Coordinate';
import { type CellValueChangedEvent } from './utils';
import type { Row } from './Row';
import type { Column } from './Column';
/**
 * A Cell is part of a grid. It contains meta information like its coordinates inside the grid and the corresponding value.
 */
export declare abstract class Cell<Value> implements Coordinate {
    readonly id: string;
    readonly row: number;
    readonly col: number;
    private _value;
    private readonly eventDispatcher;
    /**
     * @param coordinate The coordinate in the grid
     * @param value The value of the cell
     */
    protected constructor(coordinate: Coordinate, value: Value);
    /**
     * @returns the value of the cell
     */
    get value(): Value;
    /**
     * Changes the value of the cell
     */
    set value(value: Value);
    /**
     * @param callback A function that should be called, when the cell value changes
     * @returns a function to unregister the callback
     */
    onValueChanged(callback: (event: CellValueChangedEvent<Value>) => void): () => void;
    /**
     * @returns The row of the cell
     */
    abstract getRow(): Row<Value, Cell<Value>>;
    /**
     @returns The column of the cell
     */
    abstract getColumn(): Column<Value, Cell<Value>>;
    /**
     * @param cloneValue A custom function to clone the value of this cell (defaults to copying the value)
     * @returns The cloned cell
     */
    abstract clone(cloneValue?: (value: Value) => Value): Cell<Value>;
}
//# sourceMappingURL=Cell.d.ts.map