import type { Cell, Direction } from '@2d-game-grid/core';
import type { Grid } from './Grid';
import type { Coordinate, NeighborCoordinate } from './Coordinate';
/**
 * The representation of all neighbors of a cell
 */
export declare abstract class Neighbors<Value, CellWithValue extends Cell<Value>, AllowedDirection extends Direction> {
    protected grid: Grid<Value, CellWithValue>;
    protected coordinate: Coordinate;
    /**
     * @param grid The grid the cell is part of
     * @param coordinate The coordinate in the grid
     */
    constructor(grid: Grid<Value, CellWithValue>, coordinate: Coordinate);
    /**
     * @param direction The direction to the neighbor cell
     * @returns true if a cell in the given direction exists in the grid
     */
    exists(direction: AllowedDirection): boolean;
    /**
     * @param direction The direction to the neighbor cell
     * @returns The coordinate of the neighbor cell
     * @throws {NeighborDoesNotExistInGridError} when the neighbor cell does not exist in the grid
     */
    getCoordinate(direction: AllowedDirection): NeighborCoordinate;
    /**
     * @param direction The direction to the neighbor cell
     * @returns The coordinate of the neighbor cell or undefined
     */
    findCoordinate(direction: AllowedDirection): NeighborCoordinate | undefined;
    /**
     * @param directions The allowed directions
     * @returns An array of all existing neighbor cell coordinates
     */
    listCoordinates(directions: AllowedDirection[]): NeighborCoordinate[];
    /**
     * @param direction The direction to the neighbor cell
     * @returns The neighbor cell
     * @throws {NeighborDoesNotExistInGridError} when the neighbor cell does not exist in the grid
     */
    get(direction: AllowedDirection): CellWithValue;
    /**
     * @param direction The direction to the neighbor cell
     * @returns The neighbor cell or undefined
     */
    find(direction: AllowedDirection): CellWithValue | undefined;
    /**
     * @param directions The allowed directions
     * @returns An array of all existing neighbor cells
     */
    list(directions: AllowedDirection[]): CellWithValue[];
    /**
     * @param direction The direction to the neighbor cell
     * @returns The offset in the direction (row and col are either -1, 0 or 1)
     */
    protected abstract getOffsetCoordinate(direction: AllowedDirection): Coordinate;
}
//# sourceMappingURL=Neighbors.d.ts.map